@@ -30,7 +30,7 @@ use Rose::Object::MakeMethods::Generic (
     'scalar'                => 'use_db_name',
 );
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 =head1 NAME
 
@@ -388,7 +388,9 @@ EOF
 
         #carp "class: $class";
 
-        my $template = my $this_preamble = my $this_postamble = '';
+        my $template       = '';
+        my $this_preamble  = '';
+        my $this_postamble = '';
 
         if ( $class->isa('Rose::DB::Object') ) {
 
@@ -403,7 +405,7 @@ EOF
             }
 
             if ($postamble) {
-                my $this_postamble
+                $this_postamble
                     = ref $postamble eq 'CODE'
                     ? $postamble->( $class->meta )
                     : $postamble;
@@ -602,6 +604,7 @@ sub garden_default_field {
     my $col_type = $column->type;
     my $type     = $self->column_field_map->{$col_type} || 'text';
     my $name     = $column->name;
+    my $desc     = $column->can('remarks') ? $column->remarks : '';
     my $length   = $column->can('length') ? $column->length() : 0;
     my $maxlen   = $self->text_field_size;
     if ( defined $length ) {
@@ -612,6 +615,7 @@ sub garden_default_field {
     if ( $length > $MAX_FIELD_SIZE ) {
         $length = $MAX_FIELD_SIZE;
     }
+    
     return <<EOF;
     $name => {
         id          => '$name',
@@ -622,6 +626,7 @@ sub garden_default_field {
         rank        => $tabindex,
         size        => $length,
         maxlength   => $maxlen,
+        description => q{$desc},
         },
 EOF
 }
@@ -637,6 +642,7 @@ sub garden_numeric_field {
     my $col_type = $column->type;
     my $type     = $self->column_field_map->{$col_type} || 'text';
     my $name     = $column->name;
+    my $desc     = $column->can('remarks') ? $column->remarks : '';
 
     return <<EOF;
     $name => {
@@ -648,6 +654,7 @@ sub garden_numeric_field {
         rank        => $tabindex,
         size        => 16,
         maxlength   => 32,
+        description => q{$desc},
         },
 EOF
 }
@@ -662,6 +669,7 @@ sub garden_boolean_field {
     my ( $self, $column, $label, $tabindex ) = @_;
     my $col_type = $column->type;
     my $name     = $column->name;
+    my $desc     = $column->can('remarks') ? $column->remarks : '';
 
     return <<EOF;
     $name => {
@@ -671,6 +679,7 @@ sub garden_boolean_field {
         tabindex    => $tabindex,
         rank        => $tabindex,
         class       => '$col_type',
+        description => q{$desc},
         },
 EOF
 }
@@ -694,6 +703,7 @@ sub garden_text_field {
     if ( $length > $MAX_FIELD_SIZE ) {
         $length = $MAX_FIELD_SIZE;
     }
+    my $desc     = $column->can('remarks') ? $column->remarks : '';
 
     return <<EOF;
     $name => {
@@ -705,6 +715,7 @@ sub garden_text_field {
         rank        => $tabindex,
         size        => $length,
         maxlength   => $maxlen,
+        description => q{$desc},
         },
 EOF
 }
@@ -720,6 +731,7 @@ sub garden_menu_field {
     my $col_type = $column->type;
     my $name     = $column->name;
     my $options  = dump $column->values;
+    my $desc     = $column->can('remarks') ? $column->remarks : '';
 
     #dump $column;
 
@@ -732,6 +744,7 @@ sub garden_menu_field {
         tabindex    => $tabindex,
         rank        => $tabindex,
         options     => $options,
+        description => q{$desc},
         },
 EOF
 }
@@ -746,6 +759,7 @@ sub garden_textarea_field {
     my ( $self, $column, $label, $tabindex ) = @_;
     my $col_type = $column->type;
     my $name     = $column->name;
+    my $desc     = $column->can('remarks') ? $column->remarks : '';
 
     return <<EOF;
     $name => {
@@ -756,6 +770,7 @@ sub garden_textarea_field {
         tabindex    => $tabindex,
         rank        => $tabindex,
         size        => $MAX_FIELD_SIZE . 'x8',
+        description => q{$desc},
         },
 EOF
 }
@@ -770,6 +785,7 @@ sub garden_hidden_field {
     my ( $self, $column, $label, $tabindex ) = @_;
     my $col_type = $column->type;
     my $name     = $column->name;
+    my $desc     = $column->can('remarks') ? $column->remarks : '';
     return <<EOF;
     $name => {
         id      => '$name',
@@ -777,6 +793,7 @@ sub garden_hidden_field {
         class   => '$col_type',
         label   => '$label',
         rank    => $tabindex,
+        description => q{$desc},
         },
 EOF
 }
@@ -791,6 +808,8 @@ sub garden_serial_field {
     my ( $self, $column, $label, $tabindex ) = @_;
     my $col_type = $column->type;
     my $name     = $column->name;
+    my $desc     = $column->can('remarks') ? $column->remarks : '';
+    
     return <<EOF;
     $name => {
         id      => '$name',
@@ -798,6 +817,7 @@ sub garden_serial_field {
         class   => '$col_type',
         label   => '$label',
         rank    => $tabindex,
+        description => q{$desc},
         },
 EOF
 }
